@@ -22,4 +22,4 @@ ZERO_HASHES = tuple(
     )
 )
 
-BASE_TYPES = (int, bytes, bool)
+BASE_TYPES = (str, int, bytes, bool)
