@@ -23,7 +23,7 @@ class String(BasicSedes[str, str]):
             )
 
     def deserialize(self, data: bytes) -> str:
-        if len(data) != self.size:
+        if len(data) != 16:
             raise DeserializationError(
                 f"Cannot deserialize length {len(data)} byte-string as str{16}"
             )
